# phonecodes
Tools for loading dictionaries with various phonecodes (IPA, Callhome, X-SAMPA, ARPABET, DISC=CELEX), for converting among those phonecodes, and for searching those dictionaries for word sequences matching a target.

* src:
 * phonecode_tables.py - tables mapping other phonecodes to/from IPA
 * phonecodes.py - tools for converting strings
 * pronlex.py - tools for reading, writing, converting, and searching pronunciation lexicon files in several standard formats.

* test: test scripts and example files, showing how to use these tools.

